@@ -12,7 +12,8 @@ from django.db.models import Q
 from django.core.files.storage import default_storage
 
 #from captcha.fields import CaptchaField
-from simplemathcaptcha.fields import MathCaptchaField
+#from simplemathcaptcha.fields import MathCaptchaField
+from tendenci.core.base.forms import SimpleMathField
 from tinymce.widgets import TinyMCE
 
 from tendenci.core.perms.forms import TendenciBaseForm
@@ -932,7 +933,7 @@ class CreatorForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         super(CreatorForm, self).__init__(*args, **kwargs)
-        self.fields['captcha'] = MathCaptchaField(label=_('Type the code below'))
+        self.fields['captcha'] = SimpleMathField(label=_('Type the code below'))
 
 
 class CorpApproveForm(forms.Form):
